import os

from cpl_core.application import StartupABC
from cpl_core.configuration import ConfigurationABC, ConsoleArgument
from cpl_core.dependency_injection import ServiceProviderABC, ServiceCollectionABC
from cpl_core.environment import ApplicationEnvironment

from py_to_uxf_core.abc.file_scanner_abc import FileScannerABC
from py_to_uxf_core.abc.python_parser_abc import PythonParserABC
from py_to_uxf_core.abc.umlet_creator_abc import UmletCreatorABC
from py_to_uxf_core.service.file_scanner_service import FileScannerService
from py_to_uxf_core.service.python_parser_service import PythonParserService
from py_to_uxf_core.service.umlet_creator_service import UmletCreatorService


class Startup(StartupABC):

    def __init__(self):
        StartupABC.__init__(self)

    def configure_configuration(self, configuration: ConfigurationABC, environment: ApplicationEnvironment) -> ConfigurationABC:
        environment.set_runtime_directory(os.path.dirname(__file__))
        configuration.add_console_argument(ConsoleArgument('--', 'path', [], ' ', is_value_token_optional=False))
        configuration.add_console_arguments(error=False)
        return configuration

    def configure_services(self, services: ServiceCollectionABC, environment: ApplicationEnvironment) -> ServiceProviderABC:
        services.add_transient(FileScannerABC, FileScannerService)

        services.add_singleton(PythonParserABC, PythonParserService)
        services.add_singleton(UmletCreatorABC, UmletCreatorService)

        return services.build_service_provider()
